@@ -120,6 +120,32 @@ gpe_launch_get_window_for_binary (Display *dpy, const gchar *binary)
   return None;
 }
 
+gchar *
+gpe_launch_get_binary_for_window (Display *dpy, Window w)
+{
+  GSList *l;
+  struct sn_display_map *map;
+
+  for (l = sn_display_list; l; l = l->next)
+    {
+      map = l->data;
+      if (map->dpy == dpy)
+	break;
+    }
+
+  if (l == NULL)
+    return NULL;
+
+  for (l = map->client_map; l; l = l->next)
+    {
+      struct client_map *c = l->data;
+      if (c->window == w)
+	return g_strdup (c->binary);
+    }
+  
+  return NULL;
+}
+
 static void
 read_client_map (struct sn_display_map *map)
 {
@@ -254,7 +280,7 @@ sn_display_for_display (Display *dpy)
   map = g_malloc (sizeof (*map));
   map->dpy = dpy;
   map->sn_dpy = sn_display_new (dpy, NULL, NULL);
-  map->client_map_atom = XInternAtom (dpy, "_MB_CLIENT_MAP", False);
+  map->client_map_atom = XInternAtom (dpy, "_MB_CLIENT_EXEC_MAP", False);
   map->client_map = NULL;
   map->pending_startups = NULL;
   read_client_map (map);
